@@ -5,6 +5,7 @@
 #include <cstdint>
 #include <vector>
 #include "utils/stl.h"
+#include "api/api-error.h"
 
 const int kWatchDirMax = 100;
 const int kPathMaxSize = 1024;
@@ -29,6 +30,8 @@ private slots:
     void onShareLinkGenerated(const QString& link);
     void onLockFileSuccess();
     void doShowFileHistory(const QString& path);
+    void onGetSmartLinkSuccess(const QString& smart_link);
+    void onGetSmartLinkFailed(const ApiError& error);
 private:
     bool lookUpFileInformation(const QString &path, QString *repo_id, Account *account, QString *path_in_repo);
     SeafileRpcClient *rpc_client_;
